/* begincopyright
  Copyright (c) 1988 Xerox Corporation. All rights reserved.
  Use and copying of this software and preparation of derivative works based
  upon this software are permitted. Any distribution of this software or
  derivative works must comply with all applicable United States export
  control laws. This software is made available AS IS, and Xerox Corporation
  makes no warranty about the software, its performance or its conformity to
  any specification. Any person obtaining a copy of this software is requested
  to send their name and post office or electronic mail address to:
    PCR Coordinator
    Xerox PARC
    3333 Coyote Hill Rd.
    Palo Alto, CA 94304
  endcopyright */

/*
 * CirioNubLocalProcs.h
 *
 * Demers, November 5, 1990 8:49:02 am PST
 *
 * CirioNub local procedure descriptions.
 */

#ifndef _CIRIO_NUB_LOCAL_PROCS_
#define _CIRIO_NUB_LOCAL_PROCS_

#ifndef _CIRIO_NUB_TYPES_
#   include "xr/CirioNubTypes.h"
#endif


#define CIRIO_NUB_LOCAL_PROCS_LOW_VERSION	1
#define CIRIO_NUB_LOCAL_PROCS_VERSION		2


extern bool
CirioNubLocalGetIgnoreLockFailure();

extern void
CirioNubLocalSetIgnoreLockFailure(/* bool ignore */);
/*
    TRUE => local procs ignore failure to acquire load state lock and
      forge ahead anyway.
*/



extern unsigned
CirioNubLocalNull(/* unsigned desiredVersion */);
/*
    Return the "best" Cirio nub version number exported by this nub.
*/


extern int
CirioNubLocalGetThread(/* int index, CirioNubThreadData buf */);
/*
    Get data about specified thread.
    Return 0 on success, (-1) on failure (specified thread inactive).
*/


extern int
CirioNubLocalPCtoInfo(/* XR_Pointer pc, CirioNubPCInfo buf */);
/*
    Map absolute pc to info.
    Return 0 on success, (-1) on failure.
*/

/*
 * For the following procs, consult IncrementalLoad.h
 */


extern int
CirioNubLocalGetFileEntry(/* unsigned seqNum, CirioNubFileEntry buf */);
/*
    Get file entry with largest seqNum <= the specified one.
    Return 0 on success, -1 on failure.
*/


extern int
CirioNubLocalGetMatchingSymEntryByName(/*
    unsigned symID,
    char *pattern,
    bool caseSensitive,
    unsigned wantedTypes,
    unsigned ignoredClasses,
    int numToSkip,
    CirioNubSymEntry buf
*/);
/*
    Like XR_ILGetMatchingSymEntryByName.
    Returns 0 on success, (-1) on error.
*/

extern int
CirioNubLocalGetMatchingSymEntryByValue(/*
    unsigned symID,
    unsigned val,
    unsigned wantedTypes,
    unsigned ignoredClasses,
    int numToSkip,
    CirioNubSymEntry buf
*/);
/*
    Like XR_ILGetMatchingSymEntryByValue.
    Returns 0 on success, (-1) on error.
*/




/*
 * Replace a patch area ... OBSOLETE
 */

extern int
CirioNubLocalReplacePatchArea(/*
    XR_Pointer pc,
    XR_Pointer newPatchArea,
    unsigned long newSize
*/);
/*
    Replace the patch area associated with given pc value.
    If newPatchArea is NIL, CirioNubLocalReplacePatchArea will allocate
      a new patch area of the requested size.
    Return 0 on success, (-1) on failure.
*/


/*
 * Remote debugging listener query
 */

extern int
CirioNubLocalGetPort();
/*
    Return port at which local debugnub is listening.
    Return 0 if no local debugnub is running.
    Return (-1) on other failure.
*/


/*
    OBSOLETE:
*/
extern int
CirioNubLocalLookupSymEntryByName(/*
    char *sym,
    bool caseSensitive,
    bool externOnly,
    int numToSkip,
    CirioNubSymEntry buf
*/);
/*
    Lookup symbol by name,
      then skip backward the specified number of symbols.
    Return 0 on success, (-1) on error.
*/


extern int
CirioNubLocalLookupSymEntryByValue(/*
    unsigned val,
    int numToSkip,
    CirioNubSymEntry buf
*/);
/*
    Lookup symbol entry by value -- get most-recently-loaded symbol
      of highest value <= val.
    Then skip forward (numToSkip > 0) or backward (numToSkip < 0).
    Return 0 on success, (-1) on failure.
*/

extern int
CirioNubLocalLookupSymEntryByID(/*
    unsigned symID,
    CirioNubSymEntry buf
*/);
/*
    Lookup symbol entry by ID.
    This is included for completeness; it is equivalent to

        CirioNubLocalSkipSymEntryByValue(symID, 0, buf)

    See below.
*/

extern int
CirioNubLocalSkipSymEntryByName(/*
    unsigned symID,
    bool caseSensitive,
    bool externOnly,
    int numToSkip,
    CirioNubSymEntry buf
*/);
/*
    Skip forward/backward specified number of symbols by name.
    Return 0 on success, (-1) on failure.
*/

extern int
CirioNubLocalSkipSymEntryByValue(/*
    unsigned symID,
    int numToSkip,
    CirioNubSymEntry buf
*/);
/*
    Skip forward/backward specified number of symbols by value.
    Return 0 on success, (-1) on failure.
*/


extern int
CirioNubLocalGetMaxThreads();
/*
    Return max number of threads supported.
*/

extern int
CirioNubLocalGetThreadIndex(/* XR_CT t */);
/*
    Return thread index of thread t.
    If t == NIL interpret as current thread.
    Return (-1) on error (t invalid).
*/

#endif /* _CIRIO_NUB_LOCAL_PROCS_ */

